@@ -29,7 +29,7 @@ from PyQt4.QtGui import *
 from PyQt4.QtCore import *
 from PyQt4 import uic
 
-import apt_pkg
+import apt, apt_pkg
 from GDebi.DebPackage import DebPackage, Cache
 from GDebi.KDEAptDialogs import *
 
@@ -94,7 +94,7 @@ class DumbTerminal(QTextEdit):
         self._block = False
 
 class MainWindow (QDialog):
-    def __init__ (self, mode, packages):
+    def __init__ (self, mode, packages, attach=None):
         QDialog.__init__ (self)
 
         if os.path.exists("install-package.ui"):
@@ -120,19 +120,13 @@ class MainWindow (QDialog):
                     action = True
                     self.packages.append(package)
                     self.titleLabel.setText(i18nc("package name", "<b>Installing %1</b>", package))
-                    try:
-                        self._cache[package].markInstall()
-                    except SystemError, e:
-                        print "error installing '%s' (%s)" % (package, e)
+                    self._cache[package].markInstall()
             elif mode == "uninstall":
                 if self._cache[package].isInstalled:
                     action = True
                     self.packages.append(package)
                     self.titleLabel.setText(i18nc("package name", "<b>Uninstalling %1</b>", package))
-                    try:
-                        self._cache[package].markDelete()
-                    except SystemError, e:
-                        print "error removing '%s' (%s)" % (package, e)
+                    self._cache[package].markDelete()
 
         if action or mode =="update":
             if mode == "install":
@@ -163,6 +157,9 @@ class MainWindow (QDialog):
         self.connect(self.buttonBox, SIGNAL("clicked(QAbstractButton*)"), self.quit)
         QTimer.singleShot(10, self.resizing)
 
+        if attach != None:
+            KWindowSystem.setMainWindow(self, attach)
+
     def quit(self):
         self.hide()
         sys.exit() #QApplication.exit() causes a crash :(
@@ -199,11 +196,19 @@ class MainWindow (QDialog):
         self.resize(self.minimumSizeHint())
 
     def commit(self):
-        apt_pkg.PkgSystemLock()
-        if self.mode == "update":
-            result = self._cache.update(self.fprogress)
-        else:
-            result = self._cache.commit(self.fprogress,self.iprogress)
+        try:
+            apt_pkg.PkgSystemLock()
+        except SystemError, e:
+            KMessageBox.sorry(None, e.message, i18n("Error"), KMessageBox.Notify)
+            sys.exit(1)
+        try:
+            if self.mode == "update":
+                result = self._cache.update(self.fprogress)
+            else:
+                result = self._cache.commit(self.fprogress,self.iprogress)
+        except (SystemError, apt.cache.FetchFailedException), e:
+            KMessageBox.sorry(None, e.message, i18n("Error"), KMessageBox.Notify)
+            sys.exit(1)
         if result:
             if self.mode == "install":
                 if len(self.packages) == 1:
@@ -250,6 +255,7 @@ if __name__ == '__main__':
     aboutData   = KAboutData(appName, catalog, programName, version, description, license, copyright, text, homePage, bugEmail)
 
     options = KCmdLineOptions()
+    options.add("attach <winid>", ki18n("Attaches the window to an X app specified by winid"))
     options.add("install", ki18n("Install a package"))
     options.add("uninstall", ki18n("Uninstall a package"))
     options.add("update", ki18n("Reload package list"))
@@ -273,6 +279,11 @@ if __name__ == '__main__':
         KMessageBox.sorry(None, i18n("Usage: install-package --install &lt;package>, or, --uninstall &lt;package>"), i18n("Command Use"), KMessageBox.Notify)
         sys.exit(1)
 
+    if args.isSet("attach") and args.count() > 0:
+        attach = int(args.getOption("attach"))
+    else:
+        attach = None
+
     for item in range(args.count()):
         packages.append(unicode(args.arg(item)))
 
@@ -282,7 +293,7 @@ if __name__ == '__main__':
         KMessageBox.sorry(None, text, title, KMessageBox.Notify)
         sys.exit(1)
 
-    mainWindow = MainWindow(mode, packages)
+    mainWindow = MainWindow(mode, packages, attach)
     mainWindow.show()
 
     app.exec_()
